package hu.uniobuda.nik.voicerecorderwidget;

import java.io.File;
import java.io.IOException;

import android.app.Service;
import android.content.Intent;
import android.media.MediaRecorder;
import android.net.Uri;
import android.os.Environment;
import android.os.IBinder;
import android.util.Log;
import android.widget.Toast;

public class VoiceRecorderService extends Service {

	// Settings ---------------------------------------------
	public final static File recordFile = new File(Environment.getExternalStorageDirectory(), "voice_record.3gp");
	public final static String ACTION_RECORD = "hu.uniobuda.nik.voicerecorderwidget.RECORD",
							   ACTION_STOP   = "hu.uniobuda.nik.voicerecorderwidget.STOP",
							   ACTION_PLAY   = "hu.uniobuda.nik.voicerecorderwidget.PLAY";	
	
	private MediaRecorder recorder;
	private boolean run = false;

	// Recorder methods -----------------------------------------
	private void init(){
		Log.d("vrw", "init");
		// 0.) Init
		recorder = new MediaRecorder();
		recorder.setAudioSource(MediaRecorder.AudioSource.MIC);
		recorder.setOutputFormat(MediaRecorder.OutputFormat.THREE_GPP);
		recorder.setAudioEncoder(MediaRecorder.AudioEncoder.AMR_NB);
		recorder.setOutputFile(recordFile.getAbsolutePath());
	}
	
	private void stop(boolean release){
		Log.d("vrw", "stop");
		// 1.) Stop
		if(recorder != null && run){
			recorder.stop();			
			if(release) recorder.release();
			Toast.makeText(getApplicationContext(), "Felvétel leállítva.", Toast.LENGTH_LONG).show();
		}		
	}
	
	private void start(){	
		Log.d("vrw", "start");
		// 2.) Start
		try {
			stop(false);
			recorder.prepare();
			recorder.start();
			run = true;	
			Toast.makeText(getApplicationContext(), "Felvétel elindítva!", Toast.LENGTH_LONG).show();
		} catch (IllegalStateException e) {			
			stopSelf();
		} catch (IOException e) {			
			stopSelf();
		}
	}
	
	// Service Lifecycle ----------------------------------------
	@Override
	public void onCreate() {	
		super.onCreate();
		// Mivel egyszer hívódik meg !!!		
		init();
	}
	
	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		
		// 1.) Ha RECORD utasítást kapunk
		if(intent.getAction().equals(ACTION_RECORD)){
			
			// 2.) SD elérhető-e
			if(Environment.getExternalStorageState().equals(Environment.MEDIA_MOUNTED))
				start();			
			else
				Toast.makeText(getApplicationContext(), "SD kártya nem elérhető", Toast.LENGTH_LONG).show();
			
		}else if(intent.getAction().equals(ACTION_STOP)){
			// Ha leállítjuk
			stopSelf();
		}else if(intent.getAction().equals(ACTION_PLAY)){
			// Ha lejtászuk
			Uri recordFileUri = Uri.parse(recordFile.getAbsolutePath());
			Intent playIntent = new Intent(Intent.ACTION_VIEW, recordFileUri);
			       playIntent.setDataAndType(recordFileUri, "video/3gpp");
			       playIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
			startActivity(playIntent);
			
		}
		
		return super.onStartCommand(intent, flags, startId);
	}
	
	
	@Override
	public void onDestroy() {		
		super.onDestroy();
		stop(true);		
	}
	
	@Override
	public IBinder onBind(Intent intent) { return null; }

	

}
